Name:		btparser
Version:	0.26
Release:	%mkrel 2
Summary:	Parser and analyzer for backtraces produced by GDB
Group:		Development/Tools
License:	GPLv2+
URL:		http://fedorahosted.org/btparser
Source0:	https://fedorahosted.org/released/btparser/%{name}-%{version}.tar.xz
BuildRequires:	glib2-devel >= 2.21
BuildRequires:	python-devel

%description
Btparser is a backtrace parser and analyzer, which works with
backtraces produced by the GNU Project Debugger. It can parse a text
file with a backtrace to a tree of C structures, allowing to analyze
the threads and frames of the backtrace and work with them.

Btparser also contains some backtrace manipulation and extraction
routines:
- it can find a frame in the crash-time backtrace where the program
  most likely crashed (a chance is that the function described in that
  frame is buggy)
- it can produce a duplication hash of the backtrace, which helps to
  discover that two crash-time backtraces are duplicates, triggered by
  the same flaw of the code
- it can "rate" the backtrace quality, which depends on the number of
  frames with and without the function name known (missing function
  name is caused by missing debugging symbols)

%files
%doc README NEWS COPYING TODO ChangeLog
%{_bindir}/btparser
%{_mandir}/man1/%{name}.1.*

#--------------------------------------------------------------------

%define lib_major 2
%define libname %mklibname btparser %{lib_major}

%package -n %libname
Summary: Libraries for reporting crashes to different targets
Group:   System/Libraries

%description -n %libname
Btparser is a backtrace parser and analyzer, which works with
backtraces produced by the GNU Project Debugger. It can parse a text
file with a backtrace to a tree of C structures, allowing to analyze
the threads and frames of the backtrace and work with them.

Btparser also contains some backtrace manipulation and extraction
routines:
- it can find a frame in the crash-time backtrace where the program
  most likely crashed (a chance is that the function described in that
  frame is buggy)
- it can produce a duplication hash of the backtrace, which helps to
  discover that two crash-time backtraces are duplicates, triggered by
  the same flaw of the code
- it can "rate" the backtrace quality, which depends on the number of
  frames with and without the function name known (missing function
  name is caused by missing debugging symbols)

%files -n %libname
%{_libdir}/libbtparser.so.%{lib_major}*

#--------------------------------------------------------------------

%define lib_name_devel %mklibname %{name} -d

%package -n %lib_name_devel
Summary: Development libraries for %{name}
Group: Development/C
Provides: %{name}-devel = %{version}-%{release}
Provides: lib%{name}-devel = %{version}-%{release}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description -n %lib_name_devel
Development libraries and headers for %{name}.

%files -n %lib_name_devel
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*
%dir %{python_sitearch}/%{name}
%{python_sitearch}/%{name}/*

#--------------------------------------------------------------------
%prep
%setup -q

%build
%configure --disable-static
%make

%install
%makeinstall_std

# Remove all libtool archives (*.la) from modules directory.
find %{buildroot} -regex ".*\.la$" | xargs rm -f --

%check
%make check


%changelog
* Mon Oct 21 2013 umeabot <umeabot> 0.26-2.mga4
+ Revision: 538280
- Mageia 4 Mass Rebuild

* Sun Sep 29 2013 dmorgan <dmorgan> 0.26-1.mga4
+ Revision: 489184
- New version

* Sun Jul 28 2013 dams <dams> 0.25-1.mga4
+ Revision: 459275
- new version 0.25

* Fri Jan 11 2013 umeabot <umeabot> 0.20-2.mga3
+ Revision: 347210
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 25 2012 colin <colin> 0.20-1.mga3
+ Revision: 321823
- New version: 0.20

* Tue Oct 23 2012 dams <dams> 0.19-1.mga3
+ Revision: 309496
- update BR
- new version 0.19

  + malo <malo>
    - update RPM group

* Mon Jan 16 2012 dmorgan <dmorgan> 0.14-2.mga2
+ Revision: 196742
- Fix Provides

* Mon Jan 16 2012 dmorgan <dmorgan> 0.14-1.mga2
+ Revision: 196734
- imported package btparser


* Wed Nov 23 2011 Karel Klíč <kklic@redhat.com> - 0.14-1
- New upstream release

* Mon May 16 2011 Karel Klíč <kklic@redhat.com> - 0.13-1
- Initial packaging
